==> jc-1.4.0.tar.gz: soot/PrimType.h <==
// public abstract class soot.PrimType

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d6846479002a370b soot_PrimType
// @dep_class f801e5c664424a1 soot_Type

// header file dependencies
// @dep_header soot_Type

#include "soot/Type.h"

#ifndef _JC_soot_PrimType_H_
#define _JC_soot_PrimType_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_PrimType$sub_refs	_jc_soot_PrimType$sub_refs;
typedef struct _jc_soot_PrimType$sub_nonrefs	_jc_soot_PrimType$sub_nonrefs;
typedef struct _jc_soot_PrimType$refs	_jc_soot_PrimType$refs;
typedef struct _jc_soot_PrimType$nonrefs	_jc_soot_PrimType$nonrefs;
typedef struct _jc_soot_PrimType$object	_jc_soot_PrimType$object;

typedef const struct _jc_soot_PrimType$vmethods	_jc_soot_PrimType$vmethods;
typedef const struct _jc_soot_PrimType$vtable	_jc_soot_PrimType$vtable;
typedef const struct _jc_soot_PrimType$vtype	_jc_soot_PrimType$vtype;

// Constructors
extern void _jc_soot_PrimType$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_PrimType$object *);

// Virtual methods structure
struct _jc_soot_PrimType$vmethods {
};

// Vtable
struct _jc_soot_PrimType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Type$vmethods	soot_Type;
	_jc_soot_PrimType$vmethods	soot_PrimType;
};

// Vtype
struct _jc_soot_PrimType$vtype {
	_jc_type			type;
	_jc_soot_PrimType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_PrimType$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_PrimType$refs {
    _jc_soot_PrimType$sub_refs	soot_PrimType;
    _jc_soot_Type$sub_refs	soot_Type;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_PrimType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_PrimType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Type$sub_nonrefs	soot_Type;
    _jc_soot_PrimType$sub_nonrefs	soot_PrimType;
};

// Object instance structure
struct _jc_soot_PrimType$object {
	_jc_soot_PrimType$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_PrimType$vtype	*vtype;
	_jc_soot_PrimType$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_PrimType$vtype _jc_soot_PrimType$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_PrimType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_PrimType$class_object;

#endif	/* _JC_soot_PrimType_H_ */

==> jc-1.4.6.tar.gz: soot/PrimType.h <==
// public abstract class soot.PrimType

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d6846479002a370b soot_PrimType
// @dep_class f801e5c664424a1 soot_Type

// header file dependencies
// @dep_header soot_Type

#include "soot/Type.h"

#ifndef _JC_soot_PrimType_H_
#define _JC_soot_PrimType_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_PrimType$sub_refs	_jc_soot_PrimType$sub_refs;
typedef struct _jc_soot_PrimType$sub_nonrefs	_jc_soot_PrimType$sub_nonrefs;
typedef struct _jc_soot_PrimType$refs	_jc_soot_PrimType$refs;
typedef struct _jc_soot_PrimType$nonrefs	_jc_soot_PrimType$nonrefs;
typedef struct _jc_soot_PrimType$object	_jc_soot_PrimType$object;

typedef const struct _jc_soot_PrimType$vmethods	_jc_soot_PrimType$vmethods;
typedef const struct _jc_soot_PrimType$vtable	_jc_soot_PrimType$vtable;
typedef const struct _jc_soot_PrimType$vtype	_jc_soot_PrimType$vtype;

// Constructors
extern void _jc_soot_PrimType$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_PrimType$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_PrimType$vmethods {
};

// Vtable
struct _jc_soot_PrimType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Type$vmethods	soot_Type;
	_jc_soot_PrimType$vmethods	soot_PrimType;
};

// Vtype
struct _jc_soot_PrimType$vtype {
	_jc_type			type;
	_jc_soot_PrimType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_PrimType$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_PrimType$refs {
    _jc_soot_PrimType$sub_refs	soot_PrimType;
    _jc_soot_Type$sub_refs	soot_Type;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_PrimType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_PrimType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Type$sub_nonrefs	soot_Type;
    _jc_soot_PrimType$sub_nonrefs	soot_PrimType;
};

// Object instance structure
struct _jc_soot_PrimType$object {
	_jc_soot_PrimType$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_PrimType$vtype	*vtype;
	_jc_soot_PrimType$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_PrimType$vtype _jc_soot_PrimType$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_PrimType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_PrimType$class_object;

#endif	/* _JC_soot_PrimType_H_ */
